/**
 * WordPress dependencies
 */
import { privateApis } from '@wordpress/commands';
import { __ } from '@wordpress/i18n';
import { useMemo } from '@wordpress/element';
import { useSelect } from '@wordpress/data';
import { store as coreStore } from '@wordpress/core-data';
import { post, page, layout, symbolFilled } from '@wordpress/icons';
import { privateApis as routerPrivateApis } from '@wordpress/router';
import { getQueryArg, addQueryArgs, getPath } from '@wordpress/url';
/**
 * Internal dependencies
 */

import { unlock } from './lock-unlock';
const {
  useCommandLoader
} = unlock(privateApis);
const {
  useHistory
} = unlock(routerPrivateApis);
const icons = {
  post,
  page,
  wp_template: layout,
  wp_template_part: symbolFilled
};

const getNavigationCommandLoaderPerPostType = postType => function useNavigationCommandLoader(_ref) {
  let {
    search
  } = _ref;
  const history = useHistory();
  const supportsSearch = !['wp_template', 'wp_template_part'].includes(postType);
  const deps = supportsSearch ? [search] : [];
  const {
    records,
    isLoading
  } = useSelect(select => {
    const {
      getEntityRecords
    } = select(coreStore);
    const query = supportsSearch ? {
      search: !!search ? search : undefined,
      per_page: 10,
      orderby: search ? 'relevance' : 'date'
    } : {
      per_page: -1
    };
    return {
      records: getEntityRecords('postType', postType, query),
      isLoading: !select(coreStore).hasFinishedResolution('getEntityRecords', ['postType', postType, query]),
      // We're using the string literal to check whether we're in the site editor.

      /* eslint-disable-next-line @wordpress/data-no-store-string-literals */
      isSiteEditor: !!select('edit-site')
    };
  }, deps);
  const commands = useMemo(() => {
    return (records !== null && records !== void 0 ? records : []).slice(0, 10).map(record => {
      var _getPath, _record$title, _record$title2, _record$title3;

      const isSiteEditor = (_getPath = getPath(window.location.href)) === null || _getPath === void 0 ? void 0 : _getPath.includes('site-editor.php');
      const extraArgs = isSiteEditor ? {
        canvas: getQueryArg(window.location.href, 'canvas')
      } : {};
      return {
        name: ((_record$title = record.title) === null || _record$title === void 0 ? void 0 : _record$title.rendered) + ' ' + record.id,
        label: (_record$title2 = record.title) !== null && _record$title2 !== void 0 && _record$title2.rendered ? (_record$title3 = record.title) === null || _record$title3 === void 0 ? void 0 : _record$title3.rendered : __('(no title)'),
        icon: icons[postType],
        callback: _ref2 => {
          let {
            close
          } = _ref2;
          const args = {
            postType,
            postId: record.id,
            ...extraArgs
          };
          const targetUrl = addQueryArgs('site-editor.php', args);

          if (isSiteEditor) {
            history.push(args);
          } else {
            document.location = targetUrl;
          }

          close();
        }
      };
    });
  }, [records, history]);
  return {
    commands,
    isLoading
  };
};

const usePageNavigationCommandLoader = getNavigationCommandLoaderPerPostType('page');
const usePostNavigationCommandLoader = getNavigationCommandLoaderPerPostType('post');
const useTemplateNavigationCommandLoader = getNavigationCommandLoaderPerPostType('wp_template');
const useTemplatePartNavigationCommandLoader = getNavigationCommandLoaderPerPostType('wp_template_part');
export function useSiteEditorNavigationCommands() {
  useCommandLoader({
    name: 'core/edit-site/navigate-pages',
    group: __('Pages'),
    hook: usePageNavigationCommandLoader
  });
  useCommandLoader({
    name: 'core/edit-site/navigate-posts',
    group: __('Posts'),
    hook: usePostNavigationCommandLoader
  });
  useCommandLoader({
    name: 'core/edit-site/navigate-templates',
    group: __('Templates'),
    hook: useTemplateNavigationCommandLoader
  });
  useCommandLoader({
    name: 'core/edit-site/navigate-template-parts',
    group: __('Template Parts'),
    hook: useTemplatePartNavigationCommandLoader
  });
}
//# sourceMappingURL=site-editor-navigation-commands.js.map